/*
 * This file is part of the ALT project, module Alt-App-Starter.
 * Copyright (c) BaseALT Ltd 2019,2020 Pavel Moseev <mars@altlinux.org>
 *
 * This is free software; you can use this application under the GNU
 * General Public License, version 2. See the file "COPYING" for the
 * exact licensing terms.
 */

#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <KService/kservice.h>
#include <QMainWindow>
#include <QString>
#include <QStringList>

namespace Ui {
class MainWindow;
}

class MainWindow: public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = nullptr);
    ~MainWindow();

    QString processPlaceholders(const KService::Ptr &service);
    QStringList formTerminalCommand(const QStringList &command);
    void setAppName(const QString &chosenAppName);
    void processAppType(const KService::Ptr &service);

private slots:
    void runApplication();
    void chooseApplicationFromMenu();
    void chooseApplicationFromBin();

private:
    enum class terminal {
        unsupported = 0,
        konsole,
        xterm,
        xvt,
    };

    QStringList readCommandHistory();
    void saveCommandHistory(const QString &command);
    terminal getTerminalType();
    int readCurrentUserLimit();
    void checkUserPermissions();

    Ui::MainWindow *ui;

    QStringList m_commandListFromFile;
    const int m_commandHistoryLimit = 1024;
};

#endif // MAINWINDOW_H
